# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AwsCloudwatchScrapeJobArgs', 'AwsCloudwatchScrapeJob']

@pulumi.input_type
class AwsCloudwatchScrapeJobArgs:
    def __init__(__self__, *,
                 aws_account_resource_id: pulumi.Input[builtins.str],
                 stack_id: pulumi.Input[builtins.str],
                 custom_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobCustomNamespaceArgs']]]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 export_tags: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regions_subset_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 services: Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobServiceArgs']]]] = None,
                 static_labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a AwsCloudwatchScrapeJob resource.
        :param pulumi.Input[builtins.str] aws_account_resource_id: The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        :param pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobCustomNamespaceArgs']]] custom_namespaces: Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param pulumi.Input[builtins.bool] enabled: Whether the AWS CloudWatch Scrape Job is enabled or not. Defaults to `true`.
        :param pulumi.Input[builtins.bool] export_tags: When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`. Defaults to `true`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions_subset_overrides: A subset of the regions that are configured in the associated AWS Account resource to apply to this scrape job. If not set or empty, all of the Account resource's regions are scraped.
        :param pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobServiceArgs']]] services: One or more configuration blocks to configure AWS services for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] static_labels: A set of static labels to add to all metrics exported by this scrape job.
        """
        pulumi.set(__self__, "aws_account_resource_id", aws_account_resource_id)
        pulumi.set(__self__, "stack_id", stack_id)
        if custom_namespaces is not None:
            pulumi.set(__self__, "custom_namespaces", custom_namespaces)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if export_tags is not None:
            pulumi.set(__self__, "export_tags", export_tags)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if regions_subset_overrides is not None:
            pulumi.set(__self__, "regions_subset_overrides", regions_subset_overrides)
        if services is not None:
            pulumi.set(__self__, "services", services)
        if static_labels is not None:
            pulumi.set(__self__, "static_labels", static_labels)

    @property
    @pulumi.getter(name="awsAccountResourceId")
    def aws_account_resource_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        """
        return pulumi.get(self, "aws_account_resource_id")

    @aws_account_resource_id.setter
    def aws_account_resource_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "aws_account_resource_id", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter(name="customNamespaces")
    def custom_namespaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobCustomNamespaceArgs']]]]:
        """
        Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "custom_namespaces")

    @custom_namespaces.setter
    def custom_namespaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobCustomNamespaceArgs']]]]):
        pulumi.set(self, "custom_namespaces", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the AWS CloudWatch Scrape Job is enabled or not. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="exportTags")
    def export_tags(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`. Defaults to `true`.
        """
        return pulumi.get(self, "export_tags")

    @export_tags.setter
    def export_tags(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "export_tags", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="regionsSubsetOverrides")
    def regions_subset_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A subset of the regions that are configured in the associated AWS Account resource to apply to this scrape job. If not set or empty, all of the Account resource's regions are scraped.
        """
        return pulumi.get(self, "regions_subset_overrides")

    @regions_subset_overrides.setter
    def regions_subset_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "regions_subset_overrides", value)

    @property
    @pulumi.getter
    def services(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobServiceArgs']]]]:
        """
        One or more configuration blocks to configure AWS services for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "services")

    @services.setter
    def services(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobServiceArgs']]]]):
        pulumi.set(self, "services", value)

    @property
    @pulumi.getter(name="staticLabels")
    def static_labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        A set of static labels to add to all metrics exported by this scrape job.
        """
        return pulumi.get(self, "static_labels")

    @static_labels.setter
    def static_labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "static_labels", value)


@pulumi.input_type
class _AwsCloudwatchScrapeJobState:
    def __init__(__self__, *,
                 aws_account_resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 custom_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobCustomNamespaceArgs']]]] = None,
                 disabled_reason: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 export_tags: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regions_subset_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 services: Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobServiceArgs']]]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 static_labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering AwsCloudwatchScrapeJob resources.
        :param pulumi.Input[builtins.str] aws_account_resource_id: The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        :param pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobCustomNamespaceArgs']]] custom_namespaces: Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param pulumi.Input[builtins.str] disabled_reason: When the AWS CloudWatch Scrape Job is disabled, this will show the reason that it is in that state.
        :param pulumi.Input[builtins.bool] enabled: Whether the AWS CloudWatch Scrape Job is enabled or not. Defaults to `true`.
        :param pulumi.Input[builtins.bool] export_tags: When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`. Defaults to `true`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions_subset_overrides: A subset of the regions that are configured in the associated AWS Account resource to apply to this scrape job. If not set or empty, all of the Account resource's regions are scraped.
        :param pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobServiceArgs']]] services: One or more configuration blocks to configure AWS services for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] static_labels: A set of static labels to add to all metrics exported by this scrape job.
        """
        if aws_account_resource_id is not None:
            pulumi.set(__self__, "aws_account_resource_id", aws_account_resource_id)
        if custom_namespaces is not None:
            pulumi.set(__self__, "custom_namespaces", custom_namespaces)
        if disabled_reason is not None:
            pulumi.set(__self__, "disabled_reason", disabled_reason)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if export_tags is not None:
            pulumi.set(__self__, "export_tags", export_tags)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if regions_subset_overrides is not None:
            pulumi.set(__self__, "regions_subset_overrides", regions_subset_overrides)
        if services is not None:
            pulumi.set(__self__, "services", services)
        if stack_id is not None:
            pulumi.set(__self__, "stack_id", stack_id)
        if static_labels is not None:
            pulumi.set(__self__, "static_labels", static_labels)

    @property
    @pulumi.getter(name="awsAccountResourceId")
    def aws_account_resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        """
        return pulumi.get(self, "aws_account_resource_id")

    @aws_account_resource_id.setter
    def aws_account_resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "aws_account_resource_id", value)

    @property
    @pulumi.getter(name="customNamespaces")
    def custom_namespaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobCustomNamespaceArgs']]]]:
        """
        Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "custom_namespaces")

    @custom_namespaces.setter
    def custom_namespaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobCustomNamespaceArgs']]]]):
        pulumi.set(self, "custom_namespaces", value)

    @property
    @pulumi.getter(name="disabledReason")
    def disabled_reason(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When the AWS CloudWatch Scrape Job is disabled, this will show the reason that it is in that state.
        """
        return pulumi.get(self, "disabled_reason")

    @disabled_reason.setter
    def disabled_reason(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "disabled_reason", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the AWS CloudWatch Scrape Job is enabled or not. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="exportTags")
    def export_tags(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`. Defaults to `true`.
        """
        return pulumi.get(self, "export_tags")

    @export_tags.setter
    def export_tags(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "export_tags", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="regionsSubsetOverrides")
    def regions_subset_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A subset of the regions that are configured in the associated AWS Account resource to apply to this scrape job. If not set or empty, all of the Account resource's regions are scraped.
        """
        return pulumi.get(self, "regions_subset_overrides")

    @regions_subset_overrides.setter
    def regions_subset_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "regions_subset_overrides", value)

    @property
    @pulumi.getter
    def services(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobServiceArgs']]]]:
        """
        One or more configuration blocks to configure AWS services for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "services")

    @services.setter
    def services(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AwsCloudwatchScrapeJobServiceArgs']]]]):
        pulumi.set(self, "services", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter(name="staticLabels")
    def static_labels(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        A set of static labels to add to all metrics exported by this scrape job.
        """
        return pulumi.get(self, "static_labels")

    @static_labels.setter
    def static_labels(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "static_labels", value)


@pulumi.type_token("grafana:cloudProvider/awsCloudwatchScrapeJob:AwsCloudwatchScrapeJob")
class AwsCloudwatchScrapeJob(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_account_resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 custom_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobCustomNamespaceArgs', 'AwsCloudwatchScrapeJobCustomNamespaceArgsDict']]]]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 export_tags: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regions_subset_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 services: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobServiceArgs', 'AwsCloudwatchScrapeJobServiceArgsDict']]]]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 static_labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        test = grafana.cloud.get_stack(slug="gcloudstacktest")
        test_get_role = aws.iam.get_role(name="my-role")
        test_aws_account = grafana.cloud_provider.AwsAccount("test",
            stack_id=test.id,
            role_arn=test_get_role.arn,
            regions=[
                "us-east-1",
                "us-east-2",
                "us-west-1",
            ])
        test_aws_cloudwatch_scrape_job = grafana.cloud_provider.AwsCloudwatchScrapeJob("test",
            stack_id=test.id,
            name="my-cloudwatch-scrape-job",
            aws_account_resource_id=test_aws_account.resource_id,
            export_tags=True,
            services=[{
                "name": "AWS/EC2",
                "metrics": [
                    {
                        "name": "CPUUtilization",
                        "statistics": ["Average"],
                    },
                    {
                        "name": "StatusCheckFailed",
                        "statistics": ["Maximum"],
                    },
                ],
                "scrape_interval_seconds": 300,
                "resource_discovery_tag_filters": [{
                    "key": "k8s.io/cluster-autoscaler/enabled",
                    "value": "true",
                }],
                "tags_to_add_to_metrics": ["eks:cluster-name"],
            }],
            custom_namespaces=[{
                "name": "CoolApp",
                "metrics": [{
                    "name": "CoolMetric",
                    "statistics": [
                        "Maximum",
                        "Sum",
                    ],
                }],
                "scrape_interval_seconds": 300,
            }],
            static_labels={
                "label1": "value1",
                "label2": "value2",
            })
        ```

        ## Import

        ```sh
        $ pulumi import grafana:cloudProvider/awsCloudwatchScrapeJob:AwsCloudwatchScrapeJob name "{{ stack_id }}:{{ name }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] aws_account_resource_id: The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobCustomNamespaceArgs', 'AwsCloudwatchScrapeJobCustomNamespaceArgsDict']]]] custom_namespaces: Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param pulumi.Input[builtins.bool] enabled: Whether the AWS CloudWatch Scrape Job is enabled or not. Defaults to `true`.
        :param pulumi.Input[builtins.bool] export_tags: When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`. Defaults to `true`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions_subset_overrides: A subset of the regions that are configured in the associated AWS Account resource to apply to this scrape job. If not set or empty, all of the Account resource's regions are scraped.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobServiceArgs', 'AwsCloudwatchScrapeJobServiceArgsDict']]]] services: One or more configuration blocks to configure AWS services for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] static_labels: A set of static labels to add to all metrics exported by this scrape job.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AwsCloudwatchScrapeJobArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        test = grafana.cloud.get_stack(slug="gcloudstacktest")
        test_get_role = aws.iam.get_role(name="my-role")
        test_aws_account = grafana.cloud_provider.AwsAccount("test",
            stack_id=test.id,
            role_arn=test_get_role.arn,
            regions=[
                "us-east-1",
                "us-east-2",
                "us-west-1",
            ])
        test_aws_cloudwatch_scrape_job = grafana.cloud_provider.AwsCloudwatchScrapeJob("test",
            stack_id=test.id,
            name="my-cloudwatch-scrape-job",
            aws_account_resource_id=test_aws_account.resource_id,
            export_tags=True,
            services=[{
                "name": "AWS/EC2",
                "metrics": [
                    {
                        "name": "CPUUtilization",
                        "statistics": ["Average"],
                    },
                    {
                        "name": "StatusCheckFailed",
                        "statistics": ["Maximum"],
                    },
                ],
                "scrape_interval_seconds": 300,
                "resource_discovery_tag_filters": [{
                    "key": "k8s.io/cluster-autoscaler/enabled",
                    "value": "true",
                }],
                "tags_to_add_to_metrics": ["eks:cluster-name"],
            }],
            custom_namespaces=[{
                "name": "CoolApp",
                "metrics": [{
                    "name": "CoolMetric",
                    "statistics": [
                        "Maximum",
                        "Sum",
                    ],
                }],
                "scrape_interval_seconds": 300,
            }],
            static_labels={
                "label1": "value1",
                "label2": "value2",
            })
        ```

        ## Import

        ```sh
        $ pulumi import grafana:cloudProvider/awsCloudwatchScrapeJob:AwsCloudwatchScrapeJob name "{{ stack_id }}:{{ name }}"
        ```

        :param str resource_name: The name of the resource.
        :param AwsCloudwatchScrapeJobArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AwsCloudwatchScrapeJobArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_account_resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 custom_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobCustomNamespaceArgs', 'AwsCloudwatchScrapeJobCustomNamespaceArgsDict']]]]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 export_tags: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 regions_subset_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 services: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobServiceArgs', 'AwsCloudwatchScrapeJobServiceArgsDict']]]]] = None,
                 stack_id: Optional[pulumi.Input[builtins.str]] = None,
                 static_labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AwsCloudwatchScrapeJobArgs.__new__(AwsCloudwatchScrapeJobArgs)

            if aws_account_resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'aws_account_resource_id'")
            __props__.__dict__["aws_account_resource_id"] = aws_account_resource_id
            __props__.__dict__["custom_namespaces"] = custom_namespaces
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["export_tags"] = export_tags
            __props__.__dict__["name"] = name
            __props__.__dict__["regions_subset_overrides"] = regions_subset_overrides
            __props__.__dict__["services"] = services
            if stack_id is None and not opts.urn:
                raise TypeError("Missing required property 'stack_id'")
            __props__.__dict__["stack_id"] = stack_id
            __props__.__dict__["static_labels"] = static_labels
            __props__.__dict__["disabled_reason"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:cloud/providerAwsCloudwatchScrapeJob:ProviderAwsCloudwatchScrapeJob")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(AwsCloudwatchScrapeJob, __self__).__init__(
            'grafana:cloudProvider/awsCloudwatchScrapeJob:AwsCloudwatchScrapeJob',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aws_account_resource_id: Optional[pulumi.Input[builtins.str]] = None,
            custom_namespaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobCustomNamespaceArgs', 'AwsCloudwatchScrapeJobCustomNamespaceArgsDict']]]]] = None,
            disabled_reason: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            export_tags: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            regions_subset_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            services: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobServiceArgs', 'AwsCloudwatchScrapeJobServiceArgsDict']]]]] = None,
            stack_id: Optional[pulumi.Input[builtins.str]] = None,
            static_labels: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'AwsCloudwatchScrapeJob':
        """
        Get an existing AwsCloudwatchScrapeJob resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] aws_account_resource_id: The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobCustomNamespaceArgs', 'AwsCloudwatchScrapeJobCustomNamespaceArgsDict']]]] custom_namespaces: Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param pulumi.Input[builtins.str] disabled_reason: When the AWS CloudWatch Scrape Job is disabled, this will show the reason that it is in that state.
        :param pulumi.Input[builtins.bool] enabled: Whether the AWS CloudWatch Scrape Job is enabled or not. Defaults to `true`.
        :param pulumi.Input[builtins.bool] export_tags: When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`. Defaults to `true`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions_subset_overrides: A subset of the regions that are configured in the associated AWS Account resource to apply to this scrape job. If not set or empty, all of the Account resource's regions are scraped.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AwsCloudwatchScrapeJobServiceArgs', 'AwsCloudwatchScrapeJobServiceArgsDict']]]] services: One or more configuration blocks to configure AWS services for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] static_labels: A set of static labels to add to all metrics exported by this scrape job.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AwsCloudwatchScrapeJobState.__new__(_AwsCloudwatchScrapeJobState)

        __props__.__dict__["aws_account_resource_id"] = aws_account_resource_id
        __props__.__dict__["custom_namespaces"] = custom_namespaces
        __props__.__dict__["disabled_reason"] = disabled_reason
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["export_tags"] = export_tags
        __props__.__dict__["name"] = name
        __props__.__dict__["regions_subset_overrides"] = regions_subset_overrides
        __props__.__dict__["services"] = services
        __props__.__dict__["stack_id"] = stack_id
        __props__.__dict__["static_labels"] = static_labels
        return AwsCloudwatchScrapeJob(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="awsAccountResourceId")
    def aws_account_resource_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        """
        return pulumi.get(self, "aws_account_resource_id")

    @property
    @pulumi.getter(name="customNamespaces")
    def custom_namespaces(self) -> pulumi.Output[Optional[Sequence['outputs.AwsCloudwatchScrapeJobCustomNamespace']]]:
        """
        Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "custom_namespaces")

    @property
    @pulumi.getter(name="disabledReason")
    def disabled_reason(self) -> pulumi.Output[builtins.str]:
        """
        When the AWS CloudWatch Scrape Job is disabled, this will show the reason that it is in that state.
        """
        return pulumi.get(self, "disabled_reason")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Whether the AWS CloudWatch Scrape Job is enabled or not. Defaults to `true`.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="exportTags")
    def export_tags(self) -> pulumi.Output[builtins.bool]:
        """
        When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`. Defaults to `true`.
        """
        return pulumi.get(self, "export_tags")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="regionsSubsetOverrides")
    def regions_subset_overrides(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        A subset of the regions that are configured in the associated AWS Account resource to apply to this scrape job. If not set or empty, all of the Account resource's regions are scraped.
        """
        return pulumi.get(self, "regions_subset_overrides")

    @property
    @pulumi.getter
    def services(self) -> pulumi.Output[Optional[Sequence['outputs.AwsCloudwatchScrapeJobService']]]:
        """
        One or more configuration blocks to configure AWS services for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "services")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter(name="staticLabels")
    def static_labels(self) -> pulumi.Output[Mapping[str, builtins.str]]:
        """
        A set of static labels to add to all metrics exported by this scrape job.
        """
        return pulumi.get(self, "static_labels")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ServiceAccountArgs', 'ServiceAccount']

@pulumi.input_type
class ServiceAccountArgs:
    def __init__(__self__, *,
                 role: pulumi.Input[builtins.str],
                 is_disabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ServiceAccount resource.
        :param pulumi.Input[builtins.str] role: The basic role of the service account in the organization.
        :param pulumi.Input[builtins.bool] is_disabled: The disabled status for the service account. Defaults to `false`.
        :param pulumi.Input[builtins.str] name: The name of the service account.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        pulumi.set(__self__, "role", role)
        if is_disabled is not None:
            pulumi.set(__self__, "is_disabled", is_disabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Input[builtins.str]:
        """
        The basic role of the service account in the organization.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter(name="isDisabled")
    def is_disabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        The disabled status for the service account. Defaults to `false`.
        """
        return pulumi.get(self, "is_disabled")

    @is_disabled.setter
    def is_disabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_disabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the service account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)


@pulumi.input_type
class _ServiceAccountState:
    def __init__(__self__, *,
                 is_disabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 role: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServiceAccount resources.
        :param pulumi.Input[builtins.bool] is_disabled: The disabled status for the service account. Defaults to `false`.
        :param pulumi.Input[builtins.str] name: The name of the service account.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.str] role: The basic role of the service account in the organization.
        """
        if is_disabled is not None:
            pulumi.set(__self__, "is_disabled", is_disabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter(name="isDisabled")
    def is_disabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        The disabled status for the service account. Defaults to `false`.
        """
        return pulumi.get(self, "is_disabled")

    @is_disabled.setter
    def is_disabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_disabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the service account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The basic role of the service account in the organization.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role", value)


warnings.warn("""grafana.index/serviceaccount.ServiceAccount has been deprecated in favor of grafana.oss/serviceaccount.ServiceAccount""", DeprecationWarning)


@pulumi.type_token("grafana:index/serviceAccount:ServiceAccount")
class ServiceAccount(pulumi.CustomResource):
    warnings.warn("""grafana.index/serviceaccount.ServiceAccount has been deprecated in favor of grafana.oss/serviceaccount.ServiceAccount""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_disabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 role: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        **Note:** This resource is available only with Grafana 9.1+.

        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/service-accounts/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/serviceaccount/#service-account-api)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        admin = grafana.oss.ServiceAccount("admin",
            name="admin sa",
            role="Admin",
            is_disabled=False)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/serviceAccount:ServiceAccount name "{{ id }}"
        ```

        ```sh
        $ pulumi import grafana:index/serviceAccount:ServiceAccount name "{{ orgID }}:{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] is_disabled: The disabled status for the service account. Defaults to `false`.
        :param pulumi.Input[builtins.str] name: The name of the service account.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.str] role: The basic role of the service account in the organization.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServiceAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        **Note:** This resource is available only with Grafana 9.1+.

        * [Official documentation](https://grafana.com/docs/grafana/latest/administration/service-accounts/)
        * [HTTP API](https://grafana.com/docs/grafana/latest/developers/http_api/serviceaccount/#service-account-api)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        admin = grafana.oss.ServiceAccount("admin",
            name="admin sa",
            role="Admin",
            is_disabled=False)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:index/serviceAccount:ServiceAccount name "{{ id }}"
        ```

        ```sh
        $ pulumi import grafana:index/serviceAccount:ServiceAccount name "{{ orgID }}:{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param ServiceAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServiceAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_disabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.str]] = None,
                 role: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""ServiceAccount is deprecated: grafana.index/serviceaccount.ServiceAccount has been deprecated in favor of grafana.oss/serviceaccount.ServiceAccount""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServiceAccountArgs.__new__(ServiceAccountArgs)

            __props__.__dict__["is_disabled"] = is_disabled
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/serviceAccount:ServiceAccount")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(ServiceAccount, __self__).__init__(
            'grafana:index/serviceAccount:ServiceAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            is_disabled: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            org_id: Optional[pulumi.Input[builtins.str]] = None,
            role: Optional[pulumi.Input[builtins.str]] = None) -> 'ServiceAccount':
        """
        Get an existing ServiceAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] is_disabled: The disabled status for the service account. Defaults to `false`.
        :param pulumi.Input[builtins.str] name: The name of the service account.
        :param pulumi.Input[builtins.str] org_id: The Organization ID. If not set, the Org ID defined in the provider block will be used.
        :param pulumi.Input[builtins.str] role: The basic role of the service account in the organization.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServiceAccountState.__new__(_ServiceAccountState)

        __props__.__dict__["is_disabled"] = is_disabled
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["role"] = role
        return ServiceAccount(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="isDisabled")
    def is_disabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        The disabled status for the service account. Defaults to `false`.
        """
        return pulumi.get(self, "is_disabled")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the service account.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Organization ID. If not set, the Org ID defined in the provider block will be used.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[builtins.str]:
        """
        The basic role of the service account in the organization.
        """
        return pulumi.get(self, "role")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAwsCloudwatchScrapeJobsResult',
    'AwaitableGetAwsCloudwatchScrapeJobsResult',
    'get_aws_cloudwatch_scrape_jobs',
    'get_aws_cloudwatch_scrape_jobs_output',
]

@pulumi.output_type
class GetAwsCloudwatchScrapeJobsResult:
    """
    A collection of values returned by getAwsCloudwatchScrapeJobs.
    """
    def __init__(__self__, id=None, scrape_jobs=None, stack_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if scrape_jobs and not isinstance(scrape_jobs, list):
            raise TypeError("Expected argument 'scrape_jobs' to be a list")
        pulumi.set(__self__, "scrape_jobs", scrape_jobs)
        if stack_id and not isinstance(stack_id, str):
            raise TypeError("Expected argument 'stack_id' to be a str")
        pulumi.set(__self__, "stack_id", stack_id)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="scrapeJobs")
    def scrape_jobs(self) -> Optional[Sequence['outputs.GetAwsCloudwatchScrapeJobsScrapeJobResult']]:
        """
        A list of AWS CloudWatch Scrape Job objects associated with the given StackID.
        """
        return pulumi.get(self, "scrape_jobs")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> builtins.str:
        return pulumi.get(self, "stack_id")


class AwaitableGetAwsCloudwatchScrapeJobsResult(GetAwsCloudwatchScrapeJobsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAwsCloudwatchScrapeJobsResult(
            id=self.id,
            scrape_jobs=self.scrape_jobs,
            stack_id=self.stack_id)


def get_aws_cloudwatch_scrape_jobs(scrape_jobs: Optional[Sequence[Union['GetAwsCloudwatchScrapeJobsScrapeJobArgs', 'GetAwsCloudwatchScrapeJobsScrapeJobArgsDict']]] = None,
                                   stack_id: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAwsCloudwatchScrapeJobsResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    test = grafana.cloud.get_stack(slug="gcloudstacktest")
    test_get_aws_cloudwatch_scrape_jobs = grafana.cloudProvider.get_aws_cloudwatch_scrape_jobs(stack_id=test.id)
    ```


    :param Sequence[Union['GetAwsCloudwatchScrapeJobsScrapeJobArgs', 'GetAwsCloudwatchScrapeJobsScrapeJobArgsDict']] scrape_jobs: A list of AWS CloudWatch Scrape Job objects associated with the given StackID.
    """
    __args__ = dict()
    __args__['scrapeJobs'] = scrape_jobs
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:cloudProvider/getAwsCloudwatchScrapeJobs:getAwsCloudwatchScrapeJobs', __args__, opts=opts, typ=GetAwsCloudwatchScrapeJobsResult).value

    return AwaitableGetAwsCloudwatchScrapeJobsResult(
        id=pulumi.get(__ret__, 'id'),
        scrape_jobs=pulumi.get(__ret__, 'scrape_jobs'),
        stack_id=pulumi.get(__ret__, 'stack_id'))
def get_aws_cloudwatch_scrape_jobs_output(scrape_jobs: Optional[pulumi.Input[Optional[Sequence[Union['GetAwsCloudwatchScrapeJobsScrapeJobArgs', 'GetAwsCloudwatchScrapeJobsScrapeJobArgsDict']]]]] = None,
                                          stack_id: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAwsCloudwatchScrapeJobsResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana

    test = grafana.cloud.get_stack(slug="gcloudstacktest")
    test_get_aws_cloudwatch_scrape_jobs = grafana.cloudProvider.get_aws_cloudwatch_scrape_jobs(stack_id=test.id)
    ```


    :param Sequence[Union['GetAwsCloudwatchScrapeJobsScrapeJobArgs', 'GetAwsCloudwatchScrapeJobsScrapeJobArgsDict']] scrape_jobs: A list of AWS CloudWatch Scrape Job objects associated with the given StackID.
    """
    __args__ = dict()
    __args__['scrapeJobs'] = scrape_jobs
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:cloudProvider/getAwsCloudwatchScrapeJobs:getAwsCloudwatchScrapeJobs', __args__, opts=opts, typ=GetAwsCloudwatchScrapeJobsResult)
    return __ret__.apply(lambda __response__: GetAwsCloudwatchScrapeJobsResult(
        id=pulumi.get(__response__, 'id'),
        scrape_jobs=pulumi.get(__response__, 'scrape_jobs'),
        stack_id=pulumi.get(__response__, 'stack_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LoadTestArgs', 'LoadTest']

@pulumi.input_type
class LoadTestArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[builtins.str],
                 script: pulumi.Input[builtins.str],
                 baseline_test_run_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a LoadTest resource.
        :param pulumi.Input[builtins.str] project_id: The identifier of the project this load test belongs to.
        :param pulumi.Input[builtins.str] script: The k6 test script content. Can be provided inline or via the `file()` function.
        :param pulumi.Input[builtins.str] baseline_test_run_id: Identifier of a baseline test run used for results comparison.
        :param pulumi.Input[builtins.str] name: Human-friendly identifier of the load test.
        """
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "script", script)
        if baseline_test_run_id is not None:
            pulumi.set(__self__, "baseline_test_run_id", baseline_test_run_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[builtins.str]:
        """
        The identifier of the project this load test belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def script(self) -> pulumi.Input[builtins.str]:
        """
        The k6 test script content. Can be provided inline or via the `file()` function.
        """
        return pulumi.get(self, "script")

    @script.setter
    def script(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "script", value)

    @property
    @pulumi.getter(name="baselineTestRunId")
    def baseline_test_run_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identifier of a baseline test run used for results comparison.
        """
        return pulumi.get(self, "baseline_test_run_id")

    @baseline_test_run_id.setter
    def baseline_test_run_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "baseline_test_run_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human-friendly identifier of the load test.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _LoadTestState:
    def __init__(__self__, *,
                 baseline_test_run_id: Optional[pulumi.Input[builtins.str]] = None,
                 created: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 script: Optional[pulumi.Input[builtins.str]] = None,
                 updated: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LoadTest resources.
        :param pulumi.Input[builtins.str] baseline_test_run_id: Identifier of a baseline test run used for results comparison.
        :param pulumi.Input[builtins.str] created: The date when the load test was created.
        :param pulumi.Input[builtins.str] name: Human-friendly identifier of the load test.
        :param pulumi.Input[builtins.str] project_id: The identifier of the project this load test belongs to.
        :param pulumi.Input[builtins.str] script: The k6 test script content. Can be provided inline or via the `file()` function.
        :param pulumi.Input[builtins.str] updated: The date when the load test was last updated.
        """
        if baseline_test_run_id is not None:
            pulumi.set(__self__, "baseline_test_run_id", baseline_test_run_id)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if script is not None:
            pulumi.set(__self__, "script", script)
        if updated is not None:
            pulumi.set(__self__, "updated", updated)

    @property
    @pulumi.getter(name="baselineTestRunId")
    def baseline_test_run_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identifier of a baseline test run used for results comparison.
        """
        return pulumi.get(self, "baseline_test_run_id")

    @baseline_test_run_id.setter
    def baseline_test_run_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "baseline_test_run_id", value)

    @property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The date when the load test was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Human-friendly identifier of the load test.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The identifier of the project this load test belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def script(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The k6 test script content. Can be provided inline or via the `file()` function.
        """
        return pulumi.get(self, "script")

    @script.setter
    def script(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "script", value)

    @property
    @pulumi.getter
    def updated(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The date when the load test was last updated.
        """
        return pulumi.get(self, "updated")

    @updated.setter
    def updated(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated", value)


@pulumi.type_token("grafana:k6/loadTest:LoadTest")
class LoadTest(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 baseline_test_run_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 script: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages a k6 load test.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        load_test_project = grafana.k6.Project("load_test_project", name="Terraform Load Test Project")
        test_load_test = grafana.k6.LoadTest("test_load_test",
            project_id=load_test_project.id,
            name="Terraform Test Load Test",
            script=\"\"\"export default function() {
          console.log('Hello from k6!');
        }
        \"\"\")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:k6/loadTest:LoadTest name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] baseline_test_run_id: Identifier of a baseline test run used for results comparison.
        :param pulumi.Input[builtins.str] name: Human-friendly identifier of the load test.
        :param pulumi.Input[builtins.str] project_id: The identifier of the project this load test belongs to.
        :param pulumi.Input[builtins.str] script: The k6 test script content. Can be provided inline or via the `file()` function.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LoadTestArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a k6 load test.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_grafana as grafana

        load_test_project = grafana.k6.Project("load_test_project", name="Terraform Load Test Project")
        test_load_test = grafana.k6.LoadTest("test_load_test",
            project_id=load_test_project.id,
            name="Terraform Test Load Test",
            script=\"\"\"export default function() {
          console.log('Hello from k6!');
        }
        \"\"\")
        ```

        ## Import

        ```sh
        $ pulumi import grafana:k6/loadTest:LoadTest name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param LoadTestArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoadTestArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 baseline_test_run_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 script: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoadTestArgs.__new__(LoadTestArgs)

            __props__.__dict__["baseline_test_run_id"] = baseline_test_run_id
            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if script is None and not opts.urn:
                raise TypeError("Missing required property 'script'")
            __props__.__dict__["script"] = script
            __props__.__dict__["created"] = None
            __props__.__dict__["updated"] = None
        super(LoadTest, __self__).__init__(
            'grafana:k6/loadTest:LoadTest',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            baseline_test_run_id: Optional[pulumi.Input[builtins.str]] = None,
            created: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            project_id: Optional[pulumi.Input[builtins.str]] = None,
            script: Optional[pulumi.Input[builtins.str]] = None,
            updated: Optional[pulumi.Input[builtins.str]] = None) -> 'LoadTest':
        """
        Get an existing LoadTest resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] baseline_test_run_id: Identifier of a baseline test run used for results comparison.
        :param pulumi.Input[builtins.str] created: The date when the load test was created.
        :param pulumi.Input[builtins.str] name: Human-friendly identifier of the load test.
        :param pulumi.Input[builtins.str] project_id: The identifier of the project this load test belongs to.
        :param pulumi.Input[builtins.str] script: The k6 test script content. Can be provided inline or via the `file()` function.
        :param pulumi.Input[builtins.str] updated: The date when the load test was last updated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoadTestState.__new__(_LoadTestState)

        __props__.__dict__["baseline_test_run_id"] = baseline_test_run_id
        __props__.__dict__["created"] = created
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["script"] = script
        __props__.__dict__["updated"] = updated
        return LoadTest(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="baselineTestRunId")
    def baseline_test_run_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Identifier of a baseline test run used for results comparison.
        """
        return pulumi.get(self, "baseline_test_run_id")

    @property
    @pulumi.getter
    def created(self) -> pulumi.Output[builtins.str]:
        """
        The date when the load test was created.
        """
        return pulumi.get(self, "created")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Human-friendly identifier of the load test.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.str]:
        """
        The identifier of the project this load test belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def script(self) -> pulumi.Output[builtins.str]:
        """
        The k6 test script content. Can be provided inline or via the `file()` function.
        """
        return pulumi.get(self, "script")

    @property
    @pulumi.getter
    def updated(self) -> pulumi.Output[builtins.str]:
        """
        The date when the load test was last updated.
        """
        return pulumi.get(self, "updated")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetProviderAwsCloudwatchScrapeJobResult',
    'AwaitableGetProviderAwsCloudwatchScrapeJobResult',
    'get_provider_aws_cloudwatch_scrape_job',
    'get_provider_aws_cloudwatch_scrape_job_output',
]

warnings.warn("""grafana.cloud/getproviderawscloudwatchscrapejob.getProviderAwsCloudwatchScrapeJob has been deprecated in favor of grafana.cloudprovider/getawscloudwatchscrapejob.getAwsCloudwatchScrapeJob""", DeprecationWarning)

@pulumi.output_type
class GetProviderAwsCloudwatchScrapeJobResult:
    """
    A collection of values returned by getProviderAwsCloudwatchScrapeJob.
    """
    def __init__(__self__, aws_account_resource_id=None, custom_namespaces=None, disabled_reason=None, enabled=None, export_tags=None, id=None, name=None, regions=None, regions_subset_override_used=None, role_arn=None, services=None, stack_id=None, static_labels=None):
        if aws_account_resource_id and not isinstance(aws_account_resource_id, str):
            raise TypeError("Expected argument 'aws_account_resource_id' to be a str")
        pulumi.set(__self__, "aws_account_resource_id", aws_account_resource_id)
        if custom_namespaces and not isinstance(custom_namespaces, list):
            raise TypeError("Expected argument 'custom_namespaces' to be a list")
        pulumi.set(__self__, "custom_namespaces", custom_namespaces)
        if disabled_reason and not isinstance(disabled_reason, str):
            raise TypeError("Expected argument 'disabled_reason' to be a str")
        pulumi.set(__self__, "disabled_reason", disabled_reason)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if export_tags and not isinstance(export_tags, bool):
            raise TypeError("Expected argument 'export_tags' to be a bool")
        pulumi.set(__self__, "export_tags", export_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if regions_subset_override_used and not isinstance(regions_subset_override_used, bool):
            raise TypeError("Expected argument 'regions_subset_override_used' to be a bool")
        pulumi.set(__self__, "regions_subset_override_used", regions_subset_override_used)
        if role_arn and not isinstance(role_arn, str):
            raise TypeError("Expected argument 'role_arn' to be a str")
        pulumi.set(__self__, "role_arn", role_arn)
        if services and not isinstance(services, list):
            raise TypeError("Expected argument 'services' to be a list")
        pulumi.set(__self__, "services", services)
        if stack_id and not isinstance(stack_id, str):
            raise TypeError("Expected argument 'stack_id' to be a str")
        pulumi.set(__self__, "stack_id", stack_id)
        if static_labels and not isinstance(static_labels, dict):
            raise TypeError("Expected argument 'static_labels' to be a dict")
        pulumi.set(__self__, "static_labels", static_labels)

    @property
    @pulumi.getter(name="awsAccountResourceId")
    def aws_account_resource_id(self) -> builtins.str:
        """
        The ID assigned by the Grafana Cloud Provider API to an AWS Account resource that should be associated with this AWS CloudWatch Scrape Job. This can be provided by the `resource_id` attribute of the `cloudProvider.AwsAccount` resource.
        """
        return pulumi.get(self, "aws_account_resource_id")

    @property
    @pulumi.getter(name="customNamespaces")
    def custom_namespaces(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobCustomNamespaceResult']]:
        """
        Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "custom_namespaces")

    @property
    @pulumi.getter(name="disabledReason")
    def disabled_reason(self) -> builtins.str:
        """
        When the AWS CloudWatch Scrape Job is disabled, this will show the reason that it is in that state.
        """
        return pulumi.get(self, "disabled_reason")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        Whether the AWS CloudWatch Scrape Job is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="exportTags")
    def export_tags(self) -> builtins.bool:
        """
        When enabled, AWS resource tags are exported as Prometheus labels to metrics formatted as `aws_<service_name>_info`.
        """
        return pulumi.get(self, "export_tags")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[builtins.str]:
        """
        The set of AWS region names that this AWS CloudWatch Scrape Job is configured to scrape.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="regionsSubsetOverrideUsed")
    def regions_subset_override_used(self) -> builtins.bool:
        """
        When true, the `regions` attribute will be the set of regions configured in the override. When false, the `regions` attribute will be the set of regions belonging to the AWS Account resource that is associated with this AWS CloudWatch Scrape Job.
        """
        return pulumi.get(self, "regions_subset_override_used")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> builtins.str:
        """
        The AWS ARN of the IAM role associated with the AWS Account resource that is being used by this AWS CloudWatch Scrape Job.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter
    def services(self) -> Optional[Sequence['outputs.GetProviderAwsCloudwatchScrapeJobServiceResult']]:
        """
        One or more configuration blocks to dictate what this AWS CloudWatch Scrape Job should scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
        """
        return pulumi.get(self, "services")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> builtins.str:
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter(name="staticLabels")
    def static_labels(self) -> Mapping[str, builtins.str]:
        """
        A set of static labels to add to all metrics exported by this scrape job.
        """
        return pulumi.get(self, "static_labels")


class AwaitableGetProviderAwsCloudwatchScrapeJobResult(GetProviderAwsCloudwatchScrapeJobResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProviderAwsCloudwatchScrapeJobResult(
            aws_account_resource_id=self.aws_account_resource_id,
            custom_namespaces=self.custom_namespaces,
            disabled_reason=self.disabled_reason,
            enabled=self.enabled,
            export_tags=self.export_tags,
            id=self.id,
            name=self.name,
            regions=self.regions,
            regions_subset_override_used=self.regions_subset_override_used,
            role_arn=self.role_arn,
            services=self.services,
            stack_id=self.stack_id,
            static_labels=self.static_labels)


def get_provider_aws_cloudwatch_scrape_job(custom_namespaces: Optional[Sequence[Union['GetProviderAwsCloudwatchScrapeJobCustomNamespaceArgs', 'GetProviderAwsCloudwatchScrapeJobCustomNamespaceArgsDict']]] = None,
                                           name: Optional[builtins.str] = None,
                                           services: Optional[Sequence[Union['GetProviderAwsCloudwatchScrapeJobServiceArgs', 'GetProviderAwsCloudwatchScrapeJobServiceArgsDict']]] = None,
                                           stack_id: Optional[builtins.str] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProviderAwsCloudwatchScrapeJobResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test = grafana.cloud.get_stack(slug="gcloudstacktest")
    test_get_role = aws.iam.get_role(name="my-role")
    test_aws_account = grafana.cloud_provider.AwsAccount("test",
        stack_id=test.id,
        role_arn=test_get_role.arn,
        regions=[
            "us-east-1",
            "us-east-2",
            "us-west-1",
        ])
    test_aws_cloudwatch_scrape_job = grafana.cloud_provider.AwsCloudwatchScrapeJob("test",
        stack_id=test.id,
        name="my-cloudwatch-scrape-job",
        aws_account_resource_id=test_aws_account.resource_id,
        export_tags=True,
        services=[{
            "name": "AWS/EC2",
            "metrics": [
                {
                    "name": "CPUUtilization",
                    "statistics": ["Average"],
                },
                {
                    "name": "StatusCheckFailed",
                    "statistics": ["Maximum"],
                },
            ],
            "scrape_interval_seconds": 300,
            "resource_discovery_tag_filters": [{
                "key": "k8s.io/cluster-autoscaler/enabled",
                "value": "true",
            }],
            "tags_to_add_to_metrics": ["eks:cluster-name"],
        }],
        custom_namespaces=[{
            "name": "CoolApp",
            "metrics": [{
                "name": "CoolMetric",
                "statistics": [
                    "Maximum",
                    "Sum",
                ],
            }],
            "scrape_interval_seconds": 300,
        }],
        static_labels={
            "label1": "value1",
            "label2": "value2",
        })
    test_get_aws_cloudwatch_scrape_job = test_aws_cloudwatch_scrape_job.name.apply(lambda name: grafana.cloudProvider.get_aws_cloudwatch_scrape_job(stack_id=test.id,
        name=name))
    ```


    :param Sequence[Union['GetProviderAwsCloudwatchScrapeJobCustomNamespaceArgs', 'GetProviderAwsCloudwatchScrapeJobCustomNamespaceArgsDict']] custom_namespaces: Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
    :param Sequence[Union['GetProviderAwsCloudwatchScrapeJobServiceArgs', 'GetProviderAwsCloudwatchScrapeJobServiceArgsDict']] services: One or more configuration blocks to dictate what this AWS CloudWatch Scrape Job should scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
    """
    pulumi.log.warn("""get_provider_aws_cloudwatch_scrape_job is deprecated: grafana.cloud/getproviderawscloudwatchscrapejob.getProviderAwsCloudwatchScrapeJob has been deprecated in favor of grafana.cloudprovider/getawscloudwatchscrapejob.getAwsCloudwatchScrapeJob""")
    __args__ = dict()
    __args__['customNamespaces'] = custom_namespaces
    __args__['name'] = name
    __args__['services'] = services
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:cloud/getProviderAwsCloudwatchScrapeJob:getProviderAwsCloudwatchScrapeJob', __args__, opts=opts, typ=GetProviderAwsCloudwatchScrapeJobResult).value

    return AwaitableGetProviderAwsCloudwatchScrapeJobResult(
        aws_account_resource_id=pulumi.get(__ret__, 'aws_account_resource_id'),
        custom_namespaces=pulumi.get(__ret__, 'custom_namespaces'),
        disabled_reason=pulumi.get(__ret__, 'disabled_reason'),
        enabled=pulumi.get(__ret__, 'enabled'),
        export_tags=pulumi.get(__ret__, 'export_tags'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        regions=pulumi.get(__ret__, 'regions'),
        regions_subset_override_used=pulumi.get(__ret__, 'regions_subset_override_used'),
        role_arn=pulumi.get(__ret__, 'role_arn'),
        services=pulumi.get(__ret__, 'services'),
        stack_id=pulumi.get(__ret__, 'stack_id'),
        static_labels=pulumi.get(__ret__, 'static_labels'))
def get_provider_aws_cloudwatch_scrape_job_output(custom_namespaces: Optional[pulumi.Input[Optional[Sequence[Union['GetProviderAwsCloudwatchScrapeJobCustomNamespaceArgs', 'GetProviderAwsCloudwatchScrapeJobCustomNamespaceArgsDict']]]]] = None,
                                                  name: Optional[pulumi.Input[builtins.str]] = None,
                                                  services: Optional[pulumi.Input[Optional[Sequence[Union['GetProviderAwsCloudwatchScrapeJobServiceArgs', 'GetProviderAwsCloudwatchScrapeJobServiceArgsDict']]]]] = None,
                                                  stack_id: Optional[pulumi.Input[builtins.str]] = None,
                                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProviderAwsCloudwatchScrapeJobResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test = grafana.cloud.get_stack(slug="gcloudstacktest")
    test_get_role = aws.iam.get_role(name="my-role")
    test_aws_account = grafana.cloud_provider.AwsAccount("test",
        stack_id=test.id,
        role_arn=test_get_role.arn,
        regions=[
            "us-east-1",
            "us-east-2",
            "us-west-1",
        ])
    test_aws_cloudwatch_scrape_job = grafana.cloud_provider.AwsCloudwatchScrapeJob("test",
        stack_id=test.id,
        name="my-cloudwatch-scrape-job",
        aws_account_resource_id=test_aws_account.resource_id,
        export_tags=True,
        services=[{
            "name": "AWS/EC2",
            "metrics": [
                {
                    "name": "CPUUtilization",
                    "statistics": ["Average"],
                },
                {
                    "name": "StatusCheckFailed",
                    "statistics": ["Maximum"],
                },
            ],
            "scrape_interval_seconds": 300,
            "resource_discovery_tag_filters": [{
                "key": "k8s.io/cluster-autoscaler/enabled",
                "value": "true",
            }],
            "tags_to_add_to_metrics": ["eks:cluster-name"],
        }],
        custom_namespaces=[{
            "name": "CoolApp",
            "metrics": [{
                "name": "CoolMetric",
                "statistics": [
                    "Maximum",
                    "Sum",
                ],
            }],
            "scrape_interval_seconds": 300,
        }],
        static_labels={
            "label1": "value1",
            "label2": "value2",
        })
    test_get_aws_cloudwatch_scrape_job = test_aws_cloudwatch_scrape_job.name.apply(lambda name: grafana.cloudProvider.get_aws_cloudwatch_scrape_job(stack_id=test.id,
        name=name))
    ```


    :param Sequence[Union['GetProviderAwsCloudwatchScrapeJobCustomNamespaceArgs', 'GetProviderAwsCloudwatchScrapeJobCustomNamespaceArgsDict']] custom_namespaces: Zero or more configuration blocks to configure custom namespaces for the AWS CloudWatch Scrape Job to scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
    :param Sequence[Union['GetProviderAwsCloudwatchScrapeJobServiceArgs', 'GetProviderAwsCloudwatchScrapeJobServiceArgsDict']] services: One or more configuration blocks to dictate what this AWS CloudWatch Scrape Job should scrape. Each block must have a distinct `name` attribute. When accessing this as an attribute reference, it is a list of objects.
    """
    pulumi.log.warn("""get_provider_aws_cloudwatch_scrape_job is deprecated: grafana.cloud/getproviderawscloudwatchscrapejob.getProviderAwsCloudwatchScrapeJob has been deprecated in favor of grafana.cloudprovider/getawscloudwatchscrapejob.getAwsCloudwatchScrapeJob""")
    __args__ = dict()
    __args__['customNamespaces'] = custom_namespaces
    __args__['name'] = name
    __args__['services'] = services
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:cloud/getProviderAwsCloudwatchScrapeJob:getProviderAwsCloudwatchScrapeJob', __args__, opts=opts, typ=GetProviderAwsCloudwatchScrapeJobResult)
    return __ret__.apply(lambda __response__: GetProviderAwsCloudwatchScrapeJobResult(
        aws_account_resource_id=pulumi.get(__response__, 'aws_account_resource_id'),
        custom_namespaces=pulumi.get(__response__, 'custom_namespaces'),
        disabled_reason=pulumi.get(__response__, 'disabled_reason'),
        enabled=pulumi.get(__response__, 'enabled'),
        export_tags=pulumi.get(__response__, 'export_tags'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        regions=pulumi.get(__response__, 'regions'),
        regions_subset_override_used=pulumi.get(__response__, 'regions_subset_override_used'),
        role_arn=pulumi.get(__response__, 'role_arn'),
        services=pulumi.get(__response__, 'services'),
        stack_id=pulumi.get(__response__, 'stack_id'),
        static_labels=pulumi.get(__response__, 'static_labels')))
